/*
 * Sweep, a sound wave editor.
 *
 * Copyright (C) 2000 Conrad Parker
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef __PLAY_H__
#define __PLAY_H__

#include "sweep_app.h"

void
init_playback (void);

void
play_view_all (sw_view * view);

void
play_preroll (sw_view * view);

void
play_preview_cut (sw_view * view);

void
play_view_sel (sw_view * view);

void
play_view_all_pitch (sw_view * view, gfloat pitch);

void
stop_all_playback (void);

void
sample_play (sw_sample * sample);

void
sample_update_device (sw_sample * sample);

void
pause_playback (sw_sample * s);

void
stop_playback (sw_sample * sample);

gboolean
any_playing (void);

#endif /* __PLAY_H__ */
